## dbt-bigquery 1.11.0-rc1 - November 19, 2025

### Features

- Add support for python UDFs ([#1410](https://github.com/dbt-labs/dbt-adapters/issues/1410))
- Add support for aggregate sql functions ([#1432](https://github.com/dbt-labs/dbt-adapters/issues/1432))

### Dependencies

- Bump minimum dbt-adapters to 1.19.0 ([#1421](https://github.com/dbt-labs/dbt-adapters/pull/1421))
